WebPush Channels Broadcast
==========================

|readthedocs| |travis| |master-coverage|

.. |travis| image:: https://travis-ci.org/webpush-channels/webpush-channels.svg?branch=master
    :target: https://travis-ci.org/webpush-channels/webpush-channels

.. |readthedocs| image:: https://readthedocs.org/projects/webpush-channels-broadcasting/badge/?version=latest
    :target: https://webpush-channels-broadcasting.readthedocs.io/en/latest/
    :alt: Documentation Status

.. |master-coverage| image::
    https://coveralls.io/repos/webpush-channels/webpush-channels/badge.svg?branch=master
    :alt: Coverage
    :target: https://coveralls.io/r/webpush-channels/webpush-channels

.. |pypi| image:: https://img.shields.io/pypi/v/webpush-channels.svg
    :target: https://pypi.python.org/pypi/webpush-channels


Broadcast push notifications to multiple WebPush subscriptions.

- `Documentation <http://webpush-channels-broadcasting.readthedocs.io/en/latest/>`_
